@@ -24,6 +24,13 @@ from rich.console import Console
 from rich.markdown import Markdown
 from strpdatetime import strpdatetime
 
+from osxphotos.platform import assert_macos
+
+assert_macos()
+
+from photoscript import Photo, PhotosLibrary
+
+import osxphotos.sqlite3_datetime as sqlite3_datetime
 from osxphotos._constants import _OSXPHOTOS_NONE_SENTINEL, SQLITE_CHECK_SAME_THREAD
 from osxphotos._version import __version__
 from osxphotos.cli.cli_params import TIMESTAMP_OPTION, VERBOSE_OPTION
@@ -38,17 +45,14 @@ from osxphotos.datetime_utils import (
     datetime_utc_to_local,
 )
 from osxphotos.exiftool import ExifToolCaching, get_exiftool_path
+from osxphotos.fingerprint import fingerprint
+from osxphotos.fingerprintquery import FingerprintQuery
 from osxphotos.photoinfo import PhotoInfoNone
 from osxphotos.photosalbum import PhotosAlbumPhotoScript
 from osxphotos.phototemplate import PhotoTemplate, RenderOptions
-from osxphotos.platform import assert_macos
 from osxphotos.sqlitekvstore import SQLiteKVStore
 from osxphotos.unicode import normalize_unicode
-from osxphotos.utils import pluralize
-
-assert_macos()
-
-from photoscript import Photo, PhotosLibrary
+from osxphotos.utils import get_last_library_path, pluralize
 
 from .cli_params import THEME_OPTION
 from .click_rich_echo import rich_click_echo, rich_echo_error
@@ -60,6 +64,8 @@ from .verbose import get_verbose_console, verbose_print
 # functions vs ReportWriter class used by export) and I've kept everything for import
 # self-contained in this one file
 
+# register datetime adapters/converters for sqlite3
+sqlite3_datetime.register()
 
 MetaData = namedtuple("MetaData", ["title", "description", "keywords", "location"])
 
@@ -211,6 +217,7 @@ def add_photo_to_albums(
     split_folder: str,
     exiftool_path: Path,
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> list[str]:
     """Add photo to one or more albums"""
     albums = []
@@ -225,24 +232,33 @@ def add_photo_to_albums(
     # add photo to albums
     for a in albums:
         verbose(f"Adding photo [filename]{filepath.name}[/] to album [filepath]{a}[/]")
-        photos_album = PhotosAlbumPhotoScript(
-            a, verbose=verbose, split_folder=split_folder, rich=True
-        )
-        photos_album.add(photo)
+        if not dry_run:
+            photos_album = PhotosAlbumPhotoScript(
+                a, verbose=verbose, split_folder=split_folder, rich=True
+            )
+            photos_album.add(photo)
     return albums
 
 
-def clear_photo_metadata(photo: Photo, filepath: Path, verbose: Callable[..., None]):
+def clear_photo_metadata(
+    photo: Photo, filepath: Path, verbose: Callable[..., None], dry_run: bool
+):
     """Clear any metadata (title, description, keywords) associated with Photo in the Photos Library"""
     verbose(f"Clearing metadata for [filename]{filepath.name}[/]")
+    if dry_run:
+        return
     photo.title = ""
     photo.description = ""
     photo.keywords = []
 
 
-def clear_photo_location(photo: Photo, filepath: Path, verbose: Callable[..., None]):
+def clear_photo_location(
+    photo: Photo, filepath: Path, verbose: Callable[..., None], dry_run: bool
+):
     """Clear any location (latitude, longitude) associated with Photo in the Photos Library"""
     verbose(f"Clearing location for [filename]{filepath.name}[/]")
+    if dry_run:
+        return
     photo.location = (None, None)
 
 
@@ -357,8 +373,11 @@ def set_photo_metadata(
     photo: Photo,
     metadata: MetaData,
     merge_keywords: bool,
+    dry_run: bool,
 ) -> MetaData:
     """Set metadata (title, description, keywords) for a Photo object"""
+    if dry_run:
+        return metadata
     photo.title = normalize_unicode(metadata.title)
     photo.description = normalize_unicode(metadata.description)
     keywords = metadata.keywords.copy()
@@ -377,12 +396,13 @@ def set_photo_metadata_from_exiftool(
     exiftool_path: str,
     merge_keywords: bool,
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> MetaData:
     """Set photo's metadata by reading metadata form file with exiftool"""
     verbose(f"Setting metadata and location from EXIF for [filename]{filepath.name}[/]")
     metadata = metadata_from_file(filepath, exiftool_path)
     if any([metadata.title, metadata.description, metadata.keywords]):
-        metadata = set_photo_metadata(photo, metadata, merge_keywords)
+        metadata = set_photo_metadata(photo, metadata, merge_keywords, dry_run)
         verbose(f"Set metadata for [filename]{filepath.name}[/]:")
         verbose(
             f"title='{metadata.title}', description='{metadata.description}', keywords={metadata.keywords}"
@@ -391,7 +411,8 @@ def set_photo_metadata_from_exiftool(
         verbose(f"No metadata to set for [filename]{filepath.name}[/]")
     if metadata.location[0] is not None and metadata.location[1] is not None:
         # location will be set to None, None if latitude or longitude is missing
-        photo.location = metadata.location
+        if not dry_run:
+            photo.location = metadata.location
         verbose(
             f"Set location for [filename]{filepath.name}[/]: "
             f"[num]{metadata.location[0]}[/], [num]{metadata.location[1]}[/]"
@@ -408,6 +429,7 @@ def set_photo_title(
     title_template: str,
     exiftool_path: str,
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> str:
     """Set title of photo"""
     title_text = render_photo_template(
@@ -423,7 +445,8 @@ def set_photo_title(
         verbose(
             f"Setting title of photo [filename]{filepath.name}[/] to '{title_text[0]}'"
         )
-        photo.title = normalize_unicode(title_text[0])
+        if not dry_run:
+            photo.title = normalize_unicode(title_text[0])
         return title_text[0]
     else:
         return ""
@@ -436,6 +459,7 @@ def set_photo_description(
     description_template: str,
     exiftool_path: str,
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> str:
     """Set description of photo"""
     description_text = render_photo_template(
@@ -451,7 +475,8 @@ def set_photo_description(
         verbose(
             f"Setting description of photo [filename]{filepath.name}[/] to '{description_text[0]}'"
         )
-        photo.description = normalize_unicode(description_text[0])
+        if not dry_run:
+            photo.description = normalize_unicode(description_text[0])
         return description_text[0]
     else:
         return ""
@@ -465,6 +490,7 @@ def set_photo_keywords(
     exiftool_path: str,
     merge: bool,
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> list[str]:
     """Set keywords of photo"""
     keywords = []
@@ -478,7 +504,8 @@ def set_photo_keywords(
                 keywords.extend(old_keywords)
                 keywords = list(set(keywords))
         verbose(f"Setting keywords of photo [filename]{filepath.name}[/] to {keywords}")
-        photo.keywords = keywords
+        if not dry_run:
+            photo.keywords = keywords
     return keywords
 
 
@@ -487,17 +514,23 @@ def set_photo_location(
     filepath: Path,
     location: Tuple[float, float],
     verbose: Callable[..., None],
+    dry_run: bool,
 ) -> tuple[float, float]:
     """Set location of photo"""
     verbose(
         f"Setting location of photo [filename]{filepath.name}[/] to {location[0]}, {location[1]}"
     )
-    photo.location = location
+    if not dry_run:
+        photo.location = location
     return location
 
 
 def set_photo_date_from_filename(
-    photo: Photo, filepath: Path, parse_date: str, verbose: Callable[..., None]
+    photo: Photo,
+    filepath: Path,
+    parse_date: str,
+    verbose: Callable[..., None],
+    dry_run: bool,
 ) -> datetime.datetime | None:
     """Set date of photo from filename"""
     # TODO: handle timezone (use code from timewarp), for now convert timezone to local timezone
@@ -520,7 +553,8 @@ def set_photo_date_from_filename(
     verbose(
         f"Setting date of photo [filename]{filepath.name}[/] to [time]{date.strftime('%Y-%m-%d %H:%M:%S')}[/]"
     )
-    photo.date = date
+    if not dry_run:
+        photo.date = date
     return date
 
 
@@ -998,6 +1032,19 @@ class ImportCommand(click.Command):
             Note: in Photos, only albums can contain photos and folders
             may contain albums or other folders. 
 
+            ## Duplicate Checking
+
+            By default, `osxphotos import` will import all files passed to it even if duplicates
+            exist in the Photos library. If you want to skip duplicate files, you can use the
+            `--skip-dups` option which will cause osxphotos to check for exact duplicates (based on file fingerprint)
+            and skip those files. Alternatively, you can use `--dup-check` to enable Photos' own duplicate
+            checking. If a duplicate is encountered with `--dup-check`, Photos will prompt you
+            to skip or import the duplicate file.
+
+            If you use the `--verbose` option, osxphotos will report on any duplicates it finds
+            even if you don't use `--skip-dups` or `--dup-check`.  This is useful with --dry-run
+            to see if any duplicates exist in the Photos library before importing.
+
             ## Metadata
 
             `osxphotos import` can set metadata (title, description, keywords, and location) for 
@@ -1060,7 +1107,7 @@ class ImportCommand(click.Command):
             - `{exiftool}`: Format: '{exiftool:GROUP:TAGNAME}'; use exiftool (https://exiftool.org)
             to extract metadata, in form GROUP:TAGNAME, from image.
             E.g. '{exiftool:EXIF:Make}' to get camera make, or {exiftool:IPTC:Keywords} to extract
-            keywords. See https://exiftool.org/TagNames/ for list of valid tag names.
+            keywords. See https://exiftooip=l.org/TagNames/ for list of valid tag names.
             You must specify group (e.g. EXIF, IPTC, etc) as used in `exiftool -G`.
             exiftool must be installed in the path to use this template (alternatively, you can use
             `--exiftool-path` to specify the path to exiftool.)
@@ -1317,7 +1364,21 @@ class ImportCommand(click.Command):
     "If you set '--relative-to /Volumes/photos/import' "
     "then '{filepath}' will be set to 'album/img_1234.jpg'",
 )
-@click.option("--dup-check", "-D", is_flag=True, help="Check for duplicates on import.")
+@click.option(
+    "--dup-check",
+    "-D",
+    is_flag=True,
+    help="Use Photos' built-in duplicate checkign to check for duplicates on import. "
+    "Using --dup-check will cause Photos to display a dialog box for each duplicate photo found, "
+    "requesting confirmation to import the duplicate. See also --skip-dups.",
+)
+@click.option(
+    "--skip-dups",
+    is_flag=True,
+    help="Skip duplicate photos on import; osxphotos will not import any photos that appear to be duplicates. "
+    "Unlike --dup-check, this does not use Photos' built in duplicate checking feature and "
+    "does not display a dialog box for each duplicate found. See also --dup-check.",
+)
 @click.option(
     "--split-folder",
     "-f",
@@ -1338,6 +1399,11 @@ class ImportCommand(click.Command):
     "GLOB is a Unix shell-style glob pattern, for example: '--glob \"*.jpg\"'. "
     "GLOB may be repeated to import multiple patterns.",
 )
+@click.option(
+    "--dry-run",
+    is_flag=True,
+    help="Dry run; do not actually import. Useful with --verbose to see what would be imported.",
+)
 @click.option(
     "--report",
     metavar="REPORT_FILE",
@@ -1386,8 +1452,17 @@ class ImportCommand(click.Command):
     "file you've created and function is the name of the function in the python file you want to call. "
     "The function will be passed a reference to the photo object and the path to the file that was imported. "
     "You can run more than one function by repeating the '--post-function' option with different arguments. "
+    "You may also specify a post function using a URL in format --post-function 'https://path/to/module.py::function' "
     "See Post Function below.",
 )
+@click.option(
+    "--library",
+    metavar="LIBRARY_PATH",
+    type=click.Path(exists=True),
+    help="Path to the Photos library you are importing into. This is not usually needed. "
+    "You will only need to specify this if osxphotos cannot determine the path to the library "
+    "in which case osxphotos will tell you to use the --library option when you run the import command.",
+)
 @THEME_OPTION
 @click.argument("files", nargs=-1)
 @click.pass_obj
@@ -1401,12 +1476,14 @@ def import_cli(
     clear_location,
     clear_metadata,
     description,
+    dry_run,
     dup_check,
     exiftool,
     exiftool_path,
     files,
     glob,
     keyword,
+    library,
     location,
     merge_keywords,
     no_progress,
@@ -1415,6 +1492,7 @@ def import_cli(
     relative_to,
     report,
     resume,
+    skip_dups,
     split_folder,
     theme,
     timestamp,
@@ -1474,6 +1552,15 @@ def import_cli(
     )
     import_db.about = f"osxphotos import database\n{OSXPHOTOS_ABOUT_STRING}"
 
+    # need to get the library path to initialize FingerprintQuery
+    last_library = library or get_last_library_path()
+    if not last_library:
+        rich_echo_error(
+            "[error]Could not determine path to Photos library. "
+            "Please specify path to library with --library option."
+        )
+    fq = FingerprintQuery(last_library)
+
     imported_count = 0
     error_count = 0
     skipped_count = 0
@@ -1502,31 +1589,44 @@ def import_cli(
                         continue
 
             verbose(f"Importing [filepath]{filepath}[/]")
+            if duplicates := fq.photos_by_fingerprint(fingerprint(filepath)):
+                # duplicate of file already in Photos library
+                verbose(
+                    f"File [filepath]{filepath}[/] is a duplicate of photos in the library: "
+                    f"{', '.join([f'[filename]{f}[/] ([uuid]{u}[/])' for u, f in duplicates])}"
+                )
+
             report_data[filepath] = ReportRecord(
                 filepath=filepath, filename=filepath.name
             )
             report_record = report_data[filepath]
-            photo, error = import_photo(filepath, dup_check, verbose)
-            if error:
-                error_count += 1
-                report_record.error = True
+
+            if skip_dups:
+                verbose(f"Skipping duplicate [filepath]{filepath}[/]")
+                skipped_count += 1
+                report_record.imported = False
                 continue
+
+            if not dry_run:
+                photo, error = import_photo(filepath, dup_check, verbose)
+                if error:
+                    error_count += 1
+                    report_record.error = True
+                    continue
+            else:
+                photo = None
             report_record.imported = True
             imported_count += 1
 
             if clear_metadata:
-                clear_photo_metadata(photo, filepath, verbose)
+                clear_photo_metadata(photo, filepath, verbose, dry_run)
 
             if clear_location:
-                clear_photo_location(photo, filepath, verbose)
+                clear_photo_location(photo, filepath, verbose, dry_run)
 
             if exiftool:
                 set_photo_metadata_from_exiftool(
-                    photo,
-                    filepath,
-                    exiftool_path,
-                    merge_keywords,
-                    verbose,
+                    photo, filepath, exiftool_path, merge_keywords, verbose, dry_run
                 )
 
             if title:
@@ -1537,6 +1637,7 @@ def import_cli(
                     title,
                     exiftool_path,
                     verbose,
+                    dry_run,
                 )
 
             if description:
@@ -1547,6 +1648,7 @@ def import_cli(
                     description,
                     exiftool_path,
                     verbose,
+                    dry_run,
                 )
 
             if keyword:
@@ -1558,13 +1660,16 @@ def import_cli(
                     exiftool_path,
                     merge_keywords,
                     verbose,
+                    dry_run,
                 )
 
             if location:
-                set_photo_location(photo, filepath, location, verbose)
+                set_photo_location(photo, filepath, location, verbose, dry_run)
 
             if parse_date:
-                set_photo_date_from_filename(photo, filepath, parse_date, verbose)
+                set_photo_date_from_filename(
+                    photo, filepath, parse_date, verbose, dry_run
+                )
                 # TODO: ReportRecord doesn't currently record date
 
             if album:
@@ -1576,35 +1681,38 @@ def import_cli(
                     split_folder,
                     exiftool_path,
                     verbose,
+                    dry_run,
                 )
 
             if post_function:
                 for function in post_function:
                     # post function is tuple of (function, filename.py::function_name)
                     verbose(f"Calling post-function [bold]{function[1]}")
-                    try:
-                        function[0](photo, filepath, verbose, report_record)
-                    except Exception as e:
-                        rich_echo_error(
-                            f"[error]Error running post-function [italic]{function[1]}[/italic]: {e}"
-                        )
+                    if not dry_run:
+                        try:
+                            function[0](photo, filepath, verbose, report_record)
+                        except Exception as e:
+                            rich_echo_error(
+                                f"[error]Error running post-function [italic]{function[1]}[/italic]: {e}"
+                            )
 
             # update report data
-            update_report_record(report_record, photo, filepath)
-            import_db.set(str(filepath), report_record)
+            if not dry_run:
+                update_report_record(report_record, photo, filepath)
+                import_db.set(str(filepath), report_record)
 
             progress.advance(task)
 
     import_db.close()
 
-    if report:
+    if report and not dry_run:
         write_report(report_file, report_data, append)
         verbose(f"Wrote import report to [filepath]{report_file}[/]")
 
-    skipped_str = f"[num]{skipped_count}[/] skipped" if resume else ""
+    skipped_str = f", [num]{skipped_count}[/] skipped" if resume or skip_dups else ""
     echo(
         f"Done: imported [num]{imported_count}[/] {pluralize(imported_count, 'file', 'files')}, "
         f"[num]{error_count}[/] {pluralize(error_count, 'error', 'errors')}"
-        f", {skipped_str}",
+        f"{skipped_str}",
         emoji=False,
     )
