@@ -19,9 +19,14 @@
 
 import copy
 import pathlib
+import sys
 import threading
 import time
 
+from .platform import get_macos_version
+
+assert sys.platform == "darwin"
+
 import AVFoundation
 import CoreServices
 import Foundation
@@ -34,7 +39,7 @@ from wurlitzer import pipes
 
 from .fileutil import FileUtil
 from .uti import get_preferred_uti_extension
-from .utils import get_macos_version, increment_filename
+from .utils import increment_filename
 
 __all__ = [
     "NSURL_to_path",
@@ -84,6 +89,7 @@ PHOTOKIT_NOTIFICATION_FINISHED_REQUEST = "PyPhotoKitNotificationFinishedRequest"
 # minimum amount to sleep while waiting for export
 MIN_SLEEP = 0.015
 
+
 ### utility functions
 def NSURL_to_path(url):
     """Convert URL string as represented by NSURL to a path string"""
@@ -626,7 +632,8 @@ class PhotoAsset:
 
             def handler(imageData, dataUTI, orientation, info):
                 """result handler for requestImageDataAndOrientationForAsset_options_resultHandler_
-                all returned by the request is set as properties of nonlocal data (Fetchdata object)"""
+                all returned by the request is set as properties of nonlocal data (Fetchdata object)
+                """
 
                 nonlocal requestdata
 
@@ -673,7 +680,8 @@ class PhotoAsset:
 
             def handler(data):
                 """result handler for requestImageDataAndOrientationForAsset_options_resultHandler_
-                all returned by the request is set as properties of nonlocal data (Fetchdata object)"""
+                all returned by the request is set as properties of nonlocal data (Fetchdata object)
+                """
 
                 nonlocal requestdata
 
@@ -710,7 +718,8 @@ class PhotoAsset:
 
         def handler(imageData, dataUTI, orientation, info):
             """result handler for requestImageDataAndOrientationForAsset_options_resultHandler_
-            all returned by the request is set as properties of nonlocal data (Fetchdata object)"""
+            all returned by the request is set as properties of nonlocal data (Fetchdata object)
+            """
 
             nonlocal data
 
