@@ -1,30 +1,54 @@
 """ PhotosAlbum class to create an album in default Photos library and add photos to it """
 
+from __future__ import annotations
+
+import unicodedata
 from typing import List, Optional
 
-import photoscript
 from more_itertools import chunked
-from photoscript import Album, Folder, Photo, PhotosLibrary
 
 from .photoinfo import PhotoInfo
+from .platform import assert_macos
 from .utils import noop, pluralize
 
+assert_macos()
+
+import photoscript
+from photoscript import Album, Folder, Photo, PhotosLibrary
+
 __all__ = ["PhotosAlbum", "PhotosAlbumPhotoScript"]
 
 
+def get_unicode_variants(s: str) -> list[str]:
+    """Get all unicode variants of string"""
+    variants = []
+    for form in ["NFC", "NFD", "NFKC", "NFKD"]:
+        normalized = unicodedata.normalize(form, s)
+        variants.append(normalized)
+    return variants
+
+
 def folder_by_path(folders: List[str], verbose: Optional[callable] = None) -> Folder:
     """Get (and create if necessary) a Photos Folder by path (passed as list of folder names)"""
     library = PhotosLibrary()
     verbose = verbose or noop
     top_folder_name = folders.pop(0)
-    top_folder = library.folder(top_folder_name, top_level=True)
-    if not top_folder:
+
+    for folder_variant in get_unicode_variants(top_folder_name):
+        top_folder = library.folder(folder_variant, top_level=True)
+        if top_folder is not None:
+            break
+    else:
         verbose(f"Creating folder '{top_folder_name}'")
         top_folder = library.create_folder(top_folder_name)
+
     current_folder = top_folder
     for folder_name in folders:
-        folder = current_folder.folder(folder_name)
-        if not folder:
+        for folder_variant in get_unicode_variants(folder_name):
+            folder = current_folder.folder(folder_variant)
+            if folder is not None:
+                break
+        else:
             verbose(f"Creating folder '{folder_name}'")
             folder = current_folder.create_folder(folder_name)
         current_folder = folder
@@ -41,15 +65,24 @@ def album_by_path(
         # have folders
         album_name = folders_album.pop()
         folder = folder_by_path(folders_album, verbose)
-        album = folder.album(album_name)
-        if album is None:
+        for album_variant in get_unicode_variants(album_name):
+            # Get album if it exists
+            # need to check every unicode variant to avoid creating duplicate albums with same visual representation (#1085)
+            album = folder.album(album_variant)
+            if album is not None:
+                break
+        else:
             verbose(f"Creating album '{album_name}'")
             album = folder.create_album(album_name)
     else:
         # only have album name
         album_name = folders_album[0]
-        album = library.album(album_name, top_level=True)
-        if album is None:
+        for album_variant in get_unicode_variants(album_name):
+            album = library.album(album_variant, top_level=True)
+            if album is not None:
+                break
+        else:
+            # album doesn't exist, create it
             verbose(f"Creating album '{album_name}'")
             album = library.create_album(album_name)
 
