@@ -5,6 +5,7 @@ from collections import namedtuple
 
 import pytest
 
+import osxphotos
 from osxphotos._constants import _UNKNOWN_PERSON
 
 PHOTOS_DB = "./tests/Test-10.14.6.photoslibrary/database/photos.db"
@@ -269,7 +270,7 @@ def test_attributes(photosdb):
     assert p.path.endswith(
         "/tests/Test-10.14.6.photoslibrary/Masters/2019/07/27/20190727-131650/Pumkins2.jpg"
     )
-    assert p.ismissing == False
+    assert not p.ismissing
 
 
 def test_attributes_2(photosdb):
@@ -320,28 +321,28 @@ def test_favorite(photosdb):
     photos = photosdb.photos(uuid=[UUID_DICT["favorite"]])
     assert len(photos) == 1
     p = photos[0]
-    assert p.favorite == True
+    assert p.favorite
 
 
 def test_not_favorite(photosdb):
     photos = photosdb.photos(uuid=["od0fmC7NQx+ayVr+%i06XA"])
     assert len(photos) == 1
     p = photos[0]
-    assert p.favorite == False
+    assert not p.favorite
 
 
 def test_hidden(photosdb):
     photos = photosdb.photos(uuid=[UUID_DICT["hidden"]])
     assert len(photos) == 1
     p = photos[0]
-    assert p.hidden == True
+    assert p.hidden
 
 
 def test_not_hidden(photosdb):
     photos = photosdb.photos(uuid=[UUID_DICT["not_hidden"]])
     assert len(photos) == 1
     p = photos[0]
-    assert p.hidden == False
+    assert not p.hidden
 
 
 def test_visible(photosdb):
@@ -360,7 +361,7 @@ def test_not_burst(photosdb):
     assert not p.burst
 
 
-def test_location_1(photosdb):
+def test_location_has_location(photosdb):
     # test photo with lat/lon info
     photos = photosdb.photos(uuid=[UUID_DICT["location"]])
     assert len(photos) == 1
@@ -370,22 +371,29 @@ def test_location_1(photosdb):
     assert lon == pytest.approx(-0.1318055)
 
 
-def test_location_2(photosdb):
+def test_latitude_longitude_has_location(photosdb):
+    # test photo with lat/lon info
+    photos = photosdb.photos(uuid=[UUID_DICT["location"]])
+    p = photos[0]
+    assert p.latitude == pytest.approx(51.50357167)
+    assert p.longitude == pytest.approx(-0.1318055)
+
+
+def test_latitude_longitude_no_location(photosdb):
     # test photo with no location info
     photos = photosdb.photos(uuid=[UUID_DICT["no_location"]])
-    assert len(photos) == 1
     p = photos[0]
-    lat, lon = p.location
+    lat, lon = p.latitude, p.longitude
     assert lat is None
     assert lon is None
 
 
 def test_hasadjustments1(photosdb):
-    # test hasadjustments == True
+    # test hasadjustments
     photos = photosdb.photos(uuid=[UUID_DICT["has_adjustments"]])
     assert len(photos) == 1
     p = photos[0]
-    assert p.hasadjustments == True
+    assert p.hasadjustments
 
 
 def test_hasadjustments2(photosdb):
@@ -393,7 +401,7 @@ def test_hasadjustments2(photosdb):
     photos = photosdb.photos(uuid=[UUID_DICT["no_adjustments"]])
     assert len(photos) == 1
     p = photos[0]
-    assert p.hasadjustments == False
+    assert not p.hasadjustments
 
 
 def test_external_edit1(photosdb):
@@ -402,7 +410,7 @@ def test_external_edit1(photosdb):
     assert len(photos) == 1
     p = photos[0]
 
-    assert p.external_edit == True
+    assert p.external_edit
 
 
 def test_external_edit2(photosdb):
@@ -411,7 +419,7 @@ def test_external_edit2(photosdb):
     assert len(photos) == 1
     p = photos[0]
 
-    assert p.external_edit == False
+    assert not p.external_edit
 
 
 def test_path_edited1(photosdb):
@@ -531,9 +539,10 @@ def test_photosdb_repr():
 
 
 def test_photosinfo_repr():
-    import osxphotos
     import datetime  # needed for eval to work
 
+    import osxphotos
+
     photosdb = osxphotos.PhotosDB(dbfile=PHOTOS_DB)
     photos = photosdb.photos(uuid=[UUID_DICT["favorite"]])
     photo = photos[0]
@@ -644,7 +653,7 @@ def test_raw(photosdb):
     assert photo.path_raw is None
 
 
-def test_raw():
+def test_raw_properties():
     """Test various raw properties"""
     import osxphotos
 
@@ -689,3 +698,10 @@ def test_fingerprint(photosdb):
     for uuid, fingerprint in UUID_FINGERPRINT.items():
         photo = photosdb.get_photo(uuid)
         assert photo.fingerprint == fingerprint
+
+
+def test_tables(photosdb: osxphotos.PhotosDB):
+    """Test PhotoInfo.tables"""
+    photo = photosdb.get_photo(UUID_DICT["favorite"])
+    tables = photo.tables()
+    assert tables is None
