@@ -989,7 +989,7 @@ def test_comment(photosdb_comments):
     for uuid in COMMENT_UUID_DICT:
         photo = photosdb_comments.get_photo(uuid)
         comments = photo.render_template("{comment}")
-        assert comments[0] == COMMENT_UUID_DICT[uuid]
+        assert comments[0] == sorted(COMMENT_UUID_DICT[uuid])
 
 
 def test_media_type(photosdb_cloud):
@@ -1406,3 +1406,24 @@ def test_float_concatenation(photosdb):
     rendered, _ = photo.render_template("{,+photo.location}")
     assert len(rendered) == 1
     assert rendered[0] == f"{photo.location[0]},{photo.location[1]}"
+
+
+def test_var_eval(photosdb):
+    """Test {%varname?True,False} #1318"""
+    photo = [p for p in photosdb.photos() if not p.title][0]
+    template = "{var:test,{title,}}{%test?True,False}"
+    rendered, _ = photo.render_template(template)
+    assert rendered[0] == "False"
+
+    photo = [p for p in photosdb.photos() if p.title][0]
+    template = "{var:test,{title,}}{%test?True,False}"
+    rendered, _ = photo.render_template(template)
+    assert rendered[0] == "True"
+
+
+def test_null_template(photosdb):
+    """Test that template with null value renders correctly, #1319"""
+    photo = [p for p in photosdb.photos() if not p.title][0]
+    template = "{var:test,{title,}}Foo-{%test,}-Bar"
+    rendered, _ = photo.render_template(template)
+    assert rendered[0] == "Foo--Bar"
